<?php

namespace Webkul\SalesforceConnector\Controller\Adminhtml\Categories;

use Webkul\SalesforceConnector\Helper\Category;

class ExportCategories extends \Magento\Backend\App\Action
{
    protected $_resultPageFactory;
    // protected $_categoryCollection;
    protected $_filter;
    protected $_helper;
    protected $_helperData;
    protected $_json;

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Ui\Component\MassAction\Filter $filter,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        \Webkul\SalesforceConnector\Helper\Data $data,
        Category $helper
    ) {
        parent::__construct($context);
        $this->_resultPageFactory = $resultPageFactory;
        $this->_json = $jsonHelper;
        $this->_helper = $helper;
        $this->_helperData = $data;
        $this->_filter = $filter;
    }

    public function execute()
    {
        $result = ['skip' => 0, 'err' => 0, 'success' => 0];
        if (\Webkul\SalesforceConnector\Helper\Connection::checkConnectionStatus()) {
            $params = $this->getRequest()->getParams();
            $total = $params['total'];
            $counter = $params['counter'];
            static $failure = 0;
            static $success = 0;
            if ($this->_helperData->getConfigValue('catPdt', 'synCat')) {
                $cat_ids = $params['ids'];
                if (is_array($cat_ids) && count($cat_ids) > 0) {
                    if (count($cat_ids) >= 200) {
                        $this->messageManager->addError(__('Too Many selected. Use Export Instead'));
                    } else {
                        $result = $this->_helper->exportCategories(
                            $cat_ids,
                            isset($params['update']) ? true : false
                        );
                    }
                    $success += $result['success'];
                    $failure += $result['err'];
                }
                if ($counter == $total) {
                    if ($failure > 0) {
                        $this->messageManager
                            ->addError(__('Category(s) have not been Exported at Salesforce for more details check logs.', $failure));
                    }
                    if ($success > 0) {
                        $this->messageManager
                            ->addSuccess(__('Total %1 Category(s) has been successfully Exported at Salesforce.', $success));
                    }
                }
                $result['count'] = $counter;
            } else {
                $this->messageManager
                    ->addError(__('Category sync is not enabled.Please enable and then sync'));
            }
        } else {
            $this->messageManager
                ->addError(__('Category sync is not enabled.Please enable and then sync'));
        }

        $this->getResponse()->setHeader('Content-type', 'application/json');
        $this->getResponse()->setBody($this->_json->jsonEncode($result));
    }
}
