<?php
/**
 * Webkul Software.
 *
 * @category  Webkul
 * @package   Webkul_Eshopsync
 * @author    Webkul Software Private Limited
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\SalesforceConnector\Controller\Adminhtml\Customers;

use \Magento\Backend\App\Action\Context;
use Magento\Customer\Model\Customer;
use \Magento\Framework\View\Result\PageFactory;

class GetAllExportIds extends \Magento\Backend\App\Action
{
    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $_resultPageFactory;

    /** @var \Webkul\Eshopsync\Helper\Connection */
    protected $_connection;

    /** @var \Magento\Framework\Json\Helper\Data */
    protected $_json;

    /** @var \Webkul\Eshopsync\Model\CustomerFactory */
    protected $_eshopsyncCustomer;
    
    /** @var \Magento\Customer\Model\CustomerFactory */
    protected $_customerCustomer;

    /**
     * @param \Magento\Backend\App\Action\Context        $context
     * @param \Webkul\Eshopsync\Helper\Connection        $connection
     * @param \Magento\Framework\Json\Helper\Data        $jsonHelper
     * @param \Webkul\Eshopsync\Model\CustomerFactory    $eshopsyncCustomer
     * @param \Magento\Customer\Model\CustomerFactory    $customerCustomer
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Webkul\SalesforceConnector\Helper\Connection $connection,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        \Webkul\SalesforceConnector\Model\CustomerFactory $eshopsyncCustomer,
        \Magento\Customer\Model\CustomerFactory $customerCustomer,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory
    ) {
    
        parent::__construct($context);
        $this->_resultPageFactory = $resultPageFactory;
        $this->_connection =$connection;
        $this->_json = $jsonHelper;
        $this->_eshopsyncCustomer = $eshopsyncCustomer;
        $this->_customerCustomer = $customerCustomer;
    }

    public function execute()
    {
        $exportArray = $mappingArray = [];
        $exportData = [];
        if (\Webkul\SalesforceConnector\Helper\Connection::checkConnectionStatus()) {
            $model = $this->_eshopsyncCustomer->create();
            $mappingcollection = $model->getCollection()
                ->addFieldToSelect('magento_id')
                ->addFieldToFilter('sync_status', '1')
                ->getData();
            $mappingArray = array_column($mappingcollection, 'magento_id');

            $customerCollection = $this->_customerCustomer->create()
                ->getCollection()
                ->addAttributeToSelect(
                    ['entity_id', 'email', 'firstname', 'lastname']
                );
            if ($mappingArray) {
                $customerCollection->addAttributeToFilter(
                    'entity_id',
                    ['nin' => $mappingArray]
                );
            }
            
            /** @var Customer $customer */
            foreach ($customerCollection->getItems() as $customer) {
                $exportData[] = [
                    'id' => $customer->getId(),
                    'sku' => $customer->getEmail(),
                    'name' => $customer->getFirstname() . ' ' .
                        $customer->getLastname()
                ];
            }
            if (count($exportArray) == 0) {
                $this->messageManager->addNotice(__("All Magento Customer are already Exported at Salesforce!!!"));
            }
        } else {
            $this->messageManager
                ->addError(__("Check Connection"));
        }
        
        $this->getResponse()->setHeader('Content-type', 'application/json');
        $this->getResponse()->setBody($this->_json->jsonEncode($exportData));
    }

    /*
     * Check permission via ACL resource
     */
    // protected function _isAllowed()
    // {
    //     return $this->_authorization->isAllowed('Webkul_Eshopsync::customers_getallexportids');
    // }
}
